# mlfz
Machine Learning From Zero: an educational machine learning library.

## Installation

You can install the package with

```
pip install mlfz
```

To play around with the code, you can clone the repository and install locally via
```
pip install -e .
```
